@@ -11,14 +11,15 @@ mod tests {
         field1: u8,
 
         #[ltv_field(2)]
-        field2: [u8;3],
+        field2: [u8; 3],
     }
 
-   
-
     #[test]
     fn to_and_from_ltv() {
-        let original_ltv = ExampleStruct { field1: 0x69, field2: [12,34,56] };
+        let original_ltv = ExampleStruct {
+            field1: 0x69,
+            field2: [12, 34, 56],
+        };
         let ltv_bytes = original_ltv.to_ltv();
 
         let new_ltv = ExampleStruct::from_ltv(10, &ltv_bytes).unwrap();
@@ -26,17 +27,20 @@ mod tests {
     }
 
     #[derive(Debug, Ltv, Default, PartialEq, Eq)]
-    #[object(id = 10, length_size=1)]
+    #[object(id = 10, length_size = 1)]
     struct LTVObjectExample {
         #[ltv_field(1)]
         field1: u8,
         #[ltv_field(2)]
-        field2: Option<u8>
+        field2: Option<u8>,
     }
 
     #[test]
     fn to_and_from_ltv_obj() {
-        let original_ltv = LTVObjectExample { field1: 55, field2: None };
+        let original_ltv = LTVObjectExample {
+            field1: 55,
+            field2: None,
+        };
         let ltv_bytes = original_ltv.to_ltv_object();
 
         println!("{:?}", &ltv_bytes);
@@ -46,7 +50,11 @@ mod tests {
 
     #[test]
     fn output_test() {
-        let my_object_bytes = LTVObjectExample { field1: 55, field2: None }.to_ltv_object();
+        let my_object_bytes = LTVObjectExample {
+            field1: 55,
+            field2: None,
+        }
+        .to_ltv_object();
         assert_eq!(
             my_object_bytes,
             vec![
@@ -59,17 +67,18 @@ mod tests {
         )
     }
 
-
     #[derive(Debug, LtvCollection, PartialEq, Eq)]
     #[object(byte_order=BE)]
     enum MyObjects {
         Object1(LTVObjectExample),
     }
 
-
     #[test]
     fn collection_test() {
-        let my_object = LTVObjectExample { field1: 55, field2: None };
+        let my_object = LTVObjectExample {
+            field1: 55,
+            field2: None,
+        };
         let obj_bytes = MyObjects::Object1(my_object).to_ltv();
 
         assert_eq!(
@@ -84,7 +93,10 @@ mod tests {
 
     #[test]
     fn collection_obj_test() {
-        let my_object = LTVObjectExample { field1: 55, field2: None };
+        let my_object = LTVObjectExample {
+            field1: 55,
+            field2: None,
+        };
         let obj_bytes = MyObjects::Object1(my_object).to_ltv_object();
         assert_eq!(
             obj_bytes,
@@ -100,43 +112,71 @@ mod tests {
 
     #[test]
     fn collection_obj_test_same_as_single() {
-        let o1 = LTVObjectExample { field1: 55, field2: None };
-        assert_eq!(
-            o1.to_ltv_object(),
-            MyObjects::Object1(o1).to_ltv_object()
-        );
-
+        let o1 = LTVObjectExample {
+            field1: 55,
+            field2: None,
+        };
+        assert_eq!(o1.to_ltv_object(), MyObjects::Object1(o1).to_ltv_object());
     }
 
     #[test]
     fn from_ltv_to_collection() {
-
-        let o1 = LTVObjectExample { field1: 55, field2: None };
+        let o1 = LTVObjectExample {
+            field1: 55,
+            field2: None,
+        };
         let sbytes = o1.to_ltv_object();
         let s1 = MyObjects::Object1(o1);
-       
-        
+
         let s2 = MyObjects::from_ltv_object(&sbytes).unwrap();
-        assert_eq!(
-            s1,
-            s2
-        );
+        assert_eq!(s1, s2);
     }
-     
 
     #[derive(Debug, Ltv, Default, PartialEq, Eq)]
-    #[object(id = 10, length_size=1)]
+    #[object(id = 10, length_size = 1)]
     struct LTVObjectUnnamed(u32);
 
     #[test]
     fn ltv_unnamed_strct() {
-        let num : u32 = 1234567;
-        let obj = LTVObjectUnnamed(num); 
+        let num: u32 = 1234567;
+        let obj = LTVObjectUnnamed(num);
 
         assert_eq!(
-            ltv::get_ltv::<_, {ByteOrder::BE}>(&num),
-            ltv::get_ltv::<_, {ByteOrder::BE}>(&obj)
+            ltv::get_ltv::<_, { ByteOrder::BE }>(&num),
+            ltv::get_ltv::<_, { ByteOrder::BE }>(&obj)
+        );
+
+        assert_eq!(
+            obj,
+            <LTVObjectUnnamed as LTVItem<{ ByteOrder::BE }>>::from_ltv(
+                10,
+                &ltv::get_ltv::<_, { ByteOrder::BE }>(&num)
+            )
+            .unwrap()
         );
     }
 
+    #[derive(Debug, Ltv, Default, PartialEq, Eq)]
+    #[object(id = 1, length_size = 1)]
+    struct ItemWihtUnnamedField {
+        #[ltv_field(1)]
+        pub unnamed: LTVObjectUnnamed,
+    }
+
+    #[test]
+    fn item_with_unnamed_struct_field() {
+        let num: u32 = 1234567;
+        let obj = ItemWihtUnnamedField {
+            unnamed: LTVObjectUnnamed(num),
+        };
+
+        assert_eq!(
+            obj,
+            <ItemWihtUnnamedField as LTVItem<{ ByteOrder::BE }>>::from_ltv(
+                10,
+                &ltv::get_ltv::<_, { ByteOrder::BE }>(&obj)
+            )
+            .unwrap()
+        );
+    }
 }
